@@ -1,7 +1,5 @@
-# $Id: Test_class.pm,v 1.1 2005/04/15 21:10:20 joern Exp $
-
 #-----------------------------------------------------------------------
-# Copyright (C) 2002-2005 Jrn Reder <joern AT zyn.de>.
+# Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Event::RPC, which is free software; you can
@@ -30,7 +28,7 @@ sub new {
 sub hello {
 	my $self = shift;
 	
-	return "I hold this data: '".$self->get_data."'";
+	return "Hello again. My data is: '".$self->get_data."' and event model is: $AnyEvent::MODEL";
 }
 
 sub quit {
