@@ -1,7 +1,5 @@
-# $Id: Loop.pm,v 1.2 2006/02/27 14:33:37 joern Exp $
-
 #-----------------------------------------------------------------------
-# Copyright (C) 2002-2006 Jrn Reder <joern AT zyn.de>.
+# Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Event::RPC, which is free software; you can
@@ -10,15 +8,20 @@
 
 package Event::RPC::Loop;
 
+use strict;
+use utf8;
+
 sub new {
-	my $class = shift;
-	return bless {}, $class;
+    my $class = shift;
+    return bless {}, $class;
 }
 
 1;
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Event::RPC::Loop - Mainloop Abstraction layer for Event::RPC
@@ -152,25 +155,13 @@ no need to access it through Event::RPC::Loop.
 
 =head1 AUTHORS
 
-  Jrn Reder <joern at zyn dot de>
+  Jörn Reder <joern AT zyn.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2002-2006 by Jrn Reder.
+Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
 
-This library is free software; you can redistribute it and/or modify
-it under the terms of the GNU Library General Public License as
-published by the Free Software Foundation; either version 2.1 of the
-License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307
-USA.
+This library is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
 
 =cut
